summaryrefslogtreecommitdiffstats
path: root/pkgs/by-name/fi/fish-mk-maps/fish_maps.sh
blob: 61824c7d74e73e43dd7321a20ba0b4607764999e (plain) (blame)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
#! /usr/bin/env sh

set -e

cargo build
./target/debug/bind-server > ./default.nix &
sleep 1

# bind --preset y,i backward-jump-till and repeat-jump-reverse and begin-selection repeat-jump fish_vi_yank_selection end-selection
# bind --preset y,a backward-jump and repeat-jump-reverse and begin-selection repeat-jump fish_vi_yank_selection end-selection
# bind --preset d,i backward-jump-till and repeat-jump-reverse and begin-selection repeat-jump kill-selection end-selection
# bind --preset d,a backward-jump and repeat-jump-reverse and begin-selection repeat-jump kill-selection end-selection
# bind --preset d 'fish_vi_start_operator delete'
# bind --preset c 'fish_vi_start_operator change'
# bind --preset y 'fish_vi_start_operator yank'
# bind --preset -m insert c,i backward-jump-till and repeat-jump-reverse and begin-selection repeat-jump kill-selection end-selection repaint-mode
# bind --preset -m insert c,a backward-jump and repeat-jump-reverse and begin-selection repeat-jump kill-selection end-selection repaint-mode

bind --preset -M insert ctrl-y yank
bind --preset -M insert alt-y yank-pop
bind --preset -M insert right forward-char
bind --preset -M insert left backward-char
bind --preset -M insert ctrl-right forward-token
bind --preset -M insert ctrl-left backward-token
bind --preset -M insert pageup beginning-of-history
bind --preset -M insert pagedown end-of-history
bind --preset -M insert ctrl-x fish_clipboard_copy
bind --preset -M insert ctrl-v fish_clipboard_paste
bind --preset -M insert escape "\n\ \ \ \ \ \ \ \ if\ commandline\ -P\n\ \ \ \ \ \ \ \ \ \ \ \ commandline\ -f\ cancel\n\ \ \ \ \ \ \ \ else\n\ \ \ \ \ \ \ \ \ \ \ \ set\ fish_bind_mode\ default\n\ \ \ \ \ \ \ \ \ \ \ \ if\ test\ \(count\ \(commandline\ --cut-at-cursor\ \|\ tail\ -c2\)\)\ !=\ 2\n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ commandline\ -f\ backward-char\n\ \ \ \ \ \ \ \ \ \ \ \ end\n\ \ \ \ \ \ \ \ \ \ \ \ commandline\ -f\ repaint-mode\n\ \ \ \ \ \ \ \ end\n\ \ "
bind --preset -M insert ctrl-\[ "\n\ \ \ \ \ \ \ \ if\ commandline\ -P\n\ \ \ \ \ \ \ \ \ \ \ \ commandline\ -f\ cancel\n\ \ \ \ \ \ \ \ else\n\ \ \ \ \ \ \ \ \ \ \ \ set\ fish_bind_mode\ default\n\ \ \ \ \ \ \ \ \ \ \ \ if\ test\ \(count\ \(commandline\ --cut-at-cursor\ \|\ tail\ -c2\)\)\ !=\ 2\n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ commandline\ -f\ backward-char\n\ \ \ \ \ \ \ \ \ \ \ \ end\n\ \ \ \ \ \ \ \ \ \ \ \ commandline\ -f\ repaint-mode\n\ \ \ \ \ \ \ \ end\n\ \ "
bind --preset -M insert tab complete
bind --preset -M insert ctrl-i complete
bind --preset -M insert ctrl-s pager-toggle-search
bind --preset -M insert shift-tab complete-and-search
bind --preset -M insert shift-delete history-delete or backward-delete-char
bind --preset -M insert down down-or-search
bind --preset -M insert up up-or-search
bind --preset -M insert shift-right forward-bigword
bind --preset -M insert shift-left backward-bigword
bind --preset -M insert alt-b prevd-or-backward-word
bind --preset -M insert alt-f nextd-or-forward-word
bind --preset -M insert alt-right nextd-or-forward-word
bind --preset -M insert "\e\[1\;9C" nextd-or-forward-word
bind --preset -M insert alt-left prevd-or-backward-word
bind --preset -M insert "\e\[1\;9D" prevd-or-backward-word
bind --preset -M insert alt-up history-token-search-backward
bind --preset -M insert alt-down history-token-search-forward
bind --preset -M insert "\e\[1\;9A" history-token-search-backward
bind --preset -M insert "\e\[1\;9B" history-token-search-forward
bind --preset -M insert alt-. history-token-search-backward
bind --preset -M insert alt-l __fish_list_current_token
bind --preset -M insert alt-o __fish_preview_current_file
bind --preset -M insert alt-w __fish_whatis_current_token
bind --preset -M insert ctrl-l 'status test-terminal-feature scroll-content-up && commandline -f scrollback-push' clear-screen
bind --preset -M insert ctrl-c clear-commandline
bind --preset -M insert ctrl-u backward-kill-line
bind --preset -M insert ctrl-k kill-line
bind --preset -M insert ctrl-w backward-kill-path-component
bind --preset -M insert end end-of-line
bind --preset -M insert home beginning-of-line
bind --preset -M insert alt-d 'if test "$(commandline; printf .)" = \\n.; __fish_echo dirh; else; commandline -f kill-word; end'
bind --preset -M insert ctrl-d delete-or-exit
bind --preset -M insert alt-s 'for cmd in sudo doas please run0; if command -q $cmd; fish_commandline_prepend $cmd; break; end; end'
bind --preset -M insert f1 __fish_man_page
bind --preset -M insert alt-h __fish_man_page
bind --preset -M insert alt-p __fish_paginate
bind --preset -M insert alt-# __fish_toggle_comment_commandline
bind --preset -M insert alt-e edit_command_buffer
bind --preset -M insert alt-v edit_command_buffer
bind --preset -M insert '' self-insert
bind --preset -M insert space self-insert expand-abbr
bind --preset -M insert \; self-insert expand-abbr
bind --preset -M insert \| self-insert expand-abbr
bind --preset -M insert \& self-insert expand-abbr
bind --preset -M insert \> self-insert expand-abbr
bind --preset -M insert \< self-insert expand-abbr
bind --preset -M insert shift-enter 'commandline -i \\n (commandline --search-field >/dev/null && echo --search-field)' expand-abbr
bind --preset -M insert alt-enter 'commandline -i \\n (commandline --search-field >/dev/null && echo --search-field)' expand-abbr
bind --preset -M insert \) self-insert expand-abbr
bind --preset -M insert ctrl-space 'test -n "$(commandline)" && commandline -i " " (commandline --search-field >/dev/null && echo --search-field)'
bind --preset -M insert shift-space 'commandline -i " " (commandline --search-field >/dev/null && echo --search-field)' expand-abbr
bind --preset -M insert enter execute
bind --preset -M insert ctrl-j execute
bind --preset -M insert ctrl-m execute
bind --preset -M insert ctrl-enter execute
bind --preset ctrl-y yank
bind --preset alt-y yank-pop
bind --preset right forward-char
bind --preset left backward-char
bind --preset ctrl-right forward-token
bind --preset ctrl-left backward-token
bind --preset pageup beginning-of-history
bind --preset pagedown end-of-history
bind --preset ctrl-x fish_vi_dec
bind --preset ctrl-v fish_clipboard_paste
bind --preset escape 'set -g __fish_vi_count'
bind --preset ctrl-\[ 'set -g __fish_vi_count'
bind --preset tab complete
bind --preset ctrl-i complete
bind --preset ctrl-s pager-toggle-search
bind --preset shift-tab complete-and-search
bind --preset shift-delete history-delete or backward-delete-char
bind --preset down down-or-search
bind --preset up up-or-search
bind --preset shift-right forward-bigword
bind --preset shift-left backward-bigword
bind --preset alt-b prevd-or-backward-word
bind --preset alt-f nextd-or-forward-word
bind --preset alt-right nextd-or-forward-word
bind --preset "\e\[1\;9C" nextd-or-forward-word
bind --preset alt-left prevd-or-backward-word
bind --preset "\e\[1\;9D" prevd-or-backward-word
bind --preset alt-up history-token-search-backward
bind --preset alt-down history-token-search-forward
bind --preset "\e\[1\;9A" history-token-search-backward
bind --preset "\e\[1\;9B" history-token-search-forward
bind --preset alt-. history-token-search-backward
bind --preset alt-l __fish_list_current_token
bind --preset alt-o __fish_preview_current_file
bind --preset alt-w __fish_whatis_current_token
bind --preset ctrl-l 'status test-terminal-feature scroll-content-up && commandline -f scrollback-push' clear-screen
bind --preset -m insert ctrl-c clear-commandline repaint-mode
bind --preset ctrl-u backward-kill-line
bind --preset ctrl-k kill-line
bind --preset ctrl-w backward-kill-path-component
bind --preset end end-of-line
bind --preset home beginning-of-line
bind --preset alt-d 'if test "$(commandline; printf .)" = \\n.; __fish_echo dirh; else; commandline -f kill-word; end'
bind --preset ctrl-d delete-or-exit
bind --preset alt-s 'for cmd in sudo doas please run0; if command -q $cmd; fish_commandline_prepend $cmd; break; end; end'
bind --preset f1 __fish_man_page
bind --preset alt-h __fish_man_page
bind --preset alt-p __fish_paginate
bind --preset alt-# __fish_toggle_comment_commandline
bind --preset alt-e edit_command_buffer
bind --preset alt-v edit_command_buffer
bind --preset -M visual ctrl-y yank
bind --preset -M visual alt-y yank-pop
bind --preset -M visual right forward-char
bind --preset -M visual left backward-char
bind --preset -M visual ctrl-right forward-token
bind --preset -M visual ctrl-left backward-token
bind --preset -M visual pageup beginning-of-history
bind --preset -M visual pagedown end-of-history
bind --preset -M visual ctrl-x fish_clipboard_copy
bind --preset -M visual ctrl-v fish_clipboard_paste
bind --preset -M visual -m default escape end-selection repaint-mode
bind --preset -M visual -m default ctrl-\[ end-selection repaint-mode
bind --preset -M visual tab complete
bind --preset -M visual ctrl-i complete
bind --preset -M visual ctrl-s pager-toggle-search
bind --preset -M visual shift-tab complete-and-search
bind --preset -M visual shift-delete history-delete or backward-delete-char
bind --preset -M visual down down-or-search
bind --preset -M visual up up-or-search
bind --preset -M visual shift-right forward-bigword
bind --preset -M visual shift-left backward-bigword
bind --preset -M visual alt-b prevd-or-backward-word
bind --preset -M visual alt-f nextd-or-forward-word
bind --preset -M visual alt-right nextd-or-forward-word
bind --preset -M visual "\e\[1\;9C" nextd-or-forward-word
bind --preset -M visual alt-left prevd-or-backward-word
bind --preset -M visual "\e\[1\;9D" prevd-or-backward-word
bind --preset -M visual alt-up history-token-search-backward
bind --preset -M visual alt-down history-token-search-forward
bind --preset -M visual "\e\[1\;9A" history-token-search-backward
bind --preset -M visual "\e\[1\;9B" history-token-search-forward
bind --preset -M visual alt-. history-token-search-backward
bind --preset -M visual alt-l __fish_list_current_token
bind --preset -M visual alt-o __fish_preview_current_file
bind --preset -M visual alt-w __fish_whatis_current_token
bind --preset -M visual ctrl-l 'status test-terminal-feature scroll-content-up && commandline -f scrollback-push' clear-screen
bind --preset -M visual -m default ctrl-c end-selection repaint-mode
bind --preset -M visual ctrl-u backward-kill-line
bind --preset -M visual ctrl-k kill-line
bind --preset -M visual ctrl-w backward-kill-path-component
bind --preset -M visual end end-of-line
bind --preset -M visual home beginning-of-line
bind --preset -M visual alt-d 'if test "$(commandline; printf .)" = \\n.; __fish_echo dirh; else; commandline -f kill-word; end'
bind --preset -M visual ctrl-d delete-or-exit
bind --preset -M visual alt-s 'for cmd in sudo doas please run0; if command -q $cmd; fish_commandline_prepend $cmd; break; end; end'
bind --preset -M visual f1 __fish_man_page
bind --preset -M visual alt-h __fish_man_page
bind --preset -M visual alt-p __fish_paginate
bind --preset -M visual alt-# __fish_toggle_comment_commandline
bind --preset -M visual alt-e edit_command_buffer
bind --preset -M visual alt-v edit_command_buffer
bind --preset :,q exit
bind --preset 1 'fish_vi_arg_digit 1'
bind --preset 2 'fish_vi_arg_digit 2'
bind --preset 3 'fish_vi_arg_digit 3'
bind --preset 4 'fish_vi_arg_digit 4'
bind --preset 5 'fish_vi_arg_digit 5'
bind --preset 6 'fish_vi_arg_digit 6'
bind --preset 7 'fish_vi_arg_digit 7'
bind --preset 8 'fish_vi_arg_digit 8'
bind --preset 9 'fish_vi_arg_digit 9'
bind --preset 0 'if test -n "$__fish_vi_count"; fish_vi_arg_digit 0; else; commandline -f beginning-of-line; end'
bind --preset h 'fish_vi_run_count backward-char'
bind --preset l 'fish_vi_run_count forward-char'
bind --preset k 'fish_vi_run_count up-or-search'
bind --preset j 'fish_vi_run_count down-or-search'
bind --preset b 'fish_vi_run_count backward-word'
bind --preset B 'fish_vi_run_count backward-bigword'
bind --preset g,e 'fish_vi_run_count backward-word-end'
bind --preset g,E 'fish_vi_run_count backward-bigword-end'
bind --preset w 'fish_vi_run_count forward-word-vi'
bind --preset W 'fish_vi_run_count forward-bigword-vi'
bind --preset e 'fish_vi_run_count forward-word-end'
bind --preset E 'fish_vi_run_count forward-bigword-end'
bind --preset x __fish_vi_delete_char
bind --preset X __fish_vi_backward_delete_char
bind --preset -m insert enter execute
bind --preset -m insert ctrl-j execute
bind --preset -m insert ctrl-m execute
bind --preset -m insert o 'set fish_cursor_end_mode exclusive' insert-line-under repaint-mode
bind --preset -m insert O 'set fish_cursor_end_mode exclusive' insert-line-over repaint-mode
bind --preset -m insert i repaint-mode
bind --preset -m insert I beginning-of-line repaint-mode
bind --preset -m insert a 'set fish_cursor_end_mode exclusive' forward-single-char repaint-mode
bind --preset -m insert A 'set fish_cursor_end_mode exclusive' end-of-line repaint-mode
bind --preset -m visual v begin-selection repaint-mode
bind --preset g,g beginning-of-buffer
bind --preset G end-of-buffer
bind --preset \$ end-of-line
bind --preset g,\$ end-of-line
bind --preset ^ beginning-of-line
bind --preset g,^ beginning-of-line
bind --preset _ beginning-of-line
bind --preset u undo
bind --preset ctrl-r redo
bind --preset \[ history-token-search-backward
bind --preset \] history-token-search-forward
bind --preset -m insert / history-pager repaint-mode
bind --preset -M insert ctrl-n accept-autosuggestion
bind --preset -M insert delete delete-char
bind --preset delete delete-char
bind --preset -M insert backspace backward-delete-char
bind --preset -M insert shift-backspace backward-delete-char
bind --preset backspace backward-char
bind --preset -M insert ctrl-h backward-delete-char
bind --preset ctrl-h backward-char
bind --preset g,\~ 'fish_vi_start_operator swap-case'
bind --preset -M operator escape fish_vi_operator_cancel
bind --preset -M operator ctrl-\[ fish_vi_operator_cancel
bind --preset -M operator 1 'fish_vi_arg_digit 1'
bind --preset -M operator 2 'fish_vi_arg_digit 2'
bind --preset -M operator 3 'fish_vi_arg_digit 3'
bind --preset -M operator 4 'fish_vi_arg_digit 4'
bind --preset -M operator 5 'fish_vi_arg_digit 5'
bind --preset -M operator 6 'fish_vi_arg_digit 6'
bind --preset -M operator 7 'fish_vi_arg_digit 7'
bind --preset -M operator 8 'fish_vi_arg_digit 8'
bind --preset -M operator 9 'fish_vi_arg_digit 9'
bind --preset -M operator 0 'fish_vi_exec_motion beginning-of-line'
bind --preset -M operator h 'fish_vi_exec_motion backward-char'
bind --preset -M operator l 'fish_vi_exec_motion forward-char'
bind --preset -M operator k 'fish_vi_exec_motion up-line'
bind --preset -M operator j 'fish_vi_exec_motion down-line'
bind --preset -M operator b 'fish_vi_exec_motion backward-word'
bind --preset -M operator B 'fish_vi_exec_motion backward-bigword'
bind --preset -M operator g,e 'fish_vi_exec_motion backward-word-end'
bind --preset -M operator g,E 'fish_vi_exec_motion backward-bigword-end'
bind --preset -M operator w 'fish_vi_exec_motion forward-word-vi'
bind --preset -M operator W 'fish_vi_exec_motion forward-bigword-vi'
bind --preset -M operator e 'fish_vi_exec_motion forward-word-end'
bind --preset -M operator E 'fish_vi_exec_motion forward-bigword-end'
bind --preset -M operator ^ 'fish_vi_exec_motion beginning-of-line'
bind --preset -M operator \$ 'fish_vi_exec_motion end-of-line'
bind --preset -M operator -m f f ''
bind --preset -M operator -m F F ''
bind --preset -M operator -m t t ''
bind --preset -M operator -m T T ''
bind --preset -M f '' get-key 'fish_vi_exec_motion commandline --forward-jump=$fish_key' 'set -eg fish_key'
bind --preset -M F '' get-key 'fish_vi_exec_motion commandline --backward-jump=$fish_key' 'set -eg fish_key'
bind --preset -M t '' get-key 'fish_vi_exec_motion commandline --forward-jump-till=$fish_key' 'set -eg fish_key'
bind --preset -M T '' get-key 'fish_vi_exec_motion commandline --backward-jump-till=$fish_key' 'set -eg fish_key'
bind --preset -M operator \; 'fish_vi_exec_motion repeat-jump'
bind --preset -M operator comma 'fish_vi_exec_motion repeat-jump-reverse'
bind --preset -M operator d 'fish_vi_exec_motion --linewise'
bind --preset -M operator c 'fish_vi_exec_motion --linewise'
bind --preset -M operator y 'fish_vi_exec_motion --linewise'
bind --preset -M operator \~ 'fish_vi_exec_motion --linewise'
bind --preset D kill-line
bind --preset d,\$ kill-line
bind --preset d,^ backward-kill-line
bind --preset d,0 backward-kill-line
bind --preset d,i,w kill-inner-word
bind --preset d,i,W kill-inner-bigword
bind --preset d,a,w kill-a-word
bind --preset d,a,W kill-a-bigword
bind --preset d,i,b jump-till-matching-bracket and jump-till-matching-bracket and begin-selection jump-till-matching-bracket kill-selection end-selection
bind --preset d,a,b jump-to-matching-bracket and jump-to-matching-bracket and begin-selection jump-to-matching-bracket kill-selection end-selection
bind --preset d,\; begin-selection repeat-jump kill-selection end-selection
bind --preset d,comma begin-selection repeat-jump-reverse kill-selection end-selection
bind --preset -m insert s delete-char repaint-mode
bind --preset -m insert S kill-inner-line repaint-mode
bind --preset -m insert C kill-line repaint-mode
bind --preset -m insert c,\$ kill-line repaint-mode
bind --preset -m insert c,^ backward-kill-line repaint-mode
bind --preset -m insert c,0 backward-kill-line repaint-mode
bind --preset -m insert c,i,w kill-inner-word repaint-mode
bind --preset -m insert c,i,W kill-inner-bigword repaint-mode
bind --preset -m insert c,a,w kill-a-word repaint-mode
bind --preset -m insert c,a,W kill-a-bigword repaint-mode
bind --preset -m insert c,i,b jump-till-matching-bracket and jump-till-matching-bracket and begin-selection jump-till-matching-bracket kill-selection end-selection
bind --preset -m insert c,a,b jump-to-matching-bracket and jump-to-matching-bracket and begin-selection jump-to-matching-bracket kill-selection end-selection
bind --preset \~ togglecase-char forward-single-char
bind --preset g,u downcase-word
bind --preset g,U upcase-word
bind --preset J end-of-line delete-char
bind --preset K 'man (commandline -t) 2>/dev/null; or echo -n \\a'
bind --preset \",\*,y,y fish_clipboard_copy
bind --preset \",\*,Y fish_clipboard_copy
bind --preset \",+,y,y fish_clipboard_copy
bind --preset \",+,Y fish_clipboard_copy
bind --preset Y kill-whole-line yank
bind --preset y,\$ kill-line yank
bind --preset y,^ backward-kill-line yank
bind --preset y,0 backward-kill-line yank
bind --preset y,i,w kill-inner-word yank
bind --preset y,i,W kill-inner-bigword yank
bind --preset y,a,w kill-a-word yank
bind --preset y,a,W kill-a-bigword yank
bind --preset y,i,b jump-till-matching-bracket and jump-till-matching-bracket and begin-selection jump-till-matching-bracket fish_vi_yank_selection end-selection
bind --preset y,a,b jump-to-matching-bracket and jump-to-matching-bracket and begin-selection jump-to-matching-bracket fish_vi_yank_selection end-selection
bind --preset % jump-to-matching-bracket
bind --preset f forward-jump
bind --preset F backward-jump
bind --preset t forward-jump-till
bind --preset T backward-jump-till
bind --preset \; repeat-jump
bind --preset comma repeat-jump-reverse
bind --preset p 'set -g fish_cursor_end_mode exclusive' forward-char 'set -g fish_cursor_end_mode inclusive' yank
bind --preset P yank
bind --preset g,p yank-pop
bind --preset \",\*,p 'set -g fish_cursor_end_mode exclusive' forward-char 'set -g fish_cursor_end_mode inclusive' fish_clipboard_paste
bind --preset \",\*,P fish_clipboard_paste
bind --preset \",+,p 'set -g fish_cursor_end_mode exclusive' forward-char 'set -g fish_cursor_end_mode inclusive' fish_clipboard_paste
bind --preset \",+,P fish_clipboard_paste
bind --preset -m replace_one r repaint-mode
bind --preset -M replace_one -m default '' 'set -g fish_cursor_end_mode exclusive' delete-char self-insert backward-char repaint-mode 'set -g fish_cursor_end_mode inclusive'
bind --preset -M replace_one -m default enter 'set -g fish_cursor_end_mode exclusive' 'commandline -f delete-char; commandline -i \\n; commandline -f backward-char' repaint-mode 'set -g fish_cursor_end_mode inclusive'
bind --preset -M replace_one -m default ctrl-j 'set -g fish_cursor_end_mode exclusive' 'commandline -f delete-char; commandline -i \\n; commandline -f backward-char' repaint-mode 'set -g fish_cursor_end_mode inclusive'
bind --preset -M replace_one -m default ctrl-m 'set -g fish_cursor_end_mode exclusive' 'commandline -f delete-char; commandline -i \\n; commandline -f backward-char' repaint-mode 'set -g fish_cursor_end_mode inclusive'
bind --preset -M replace_one -m default escape cancel repaint-mode
bind --preset -M replace_one -m default ctrl-\[ cancel repaint-mode
bind --preset -m replace R repaint-mode
bind --preset -M replace '' delete-char self-insert
bind --preset -M replace -m insert enter execute repaint-mode
bind --preset -M replace -m insert ctrl-j execute repaint-mode
bind --preset -M replace -m insert ctrl-m execute repaint-mode
bind --preset -M replace -m default escape cancel repaint-mode
bind --preset -M replace -m default ctrl-\[ cancel repaint-mode
bind --preset -M replace backspace backward-char
bind --preset -M replace shift-backspace backward-char
bind --preset ctrl-a fish_vi_inc
bind --preset -M visual h backward-char
bind --preset -M visual l forward-char
bind --preset -M visual k up-line
bind --preset -M visual j down-line
bind --preset -M visual b backward-word
bind --preset -M visual B backward-bigword
bind --preset -M visual g,e backward-word-end
bind --preset -M visual g,E backward-bigword-end
bind --preset -M visual w forward-word-vi
bind --preset -M visual W forward-bigword-vi
bind --preset -M visual e forward-word-end
bind --preset -M visual E forward-bigword-end
bind --preset -M visual o swap-selection-start-stop repaint-mode
bind --preset -M visual % jump-to-matching-bracket
bind --preset -M visual f forward-jump
bind --preset -M visual t forward-jump-till
bind --preset -M visual F backward-jump
bind --preset -M visual T backward-jump-till
bind --preset -M visual \; repeat-jump
bind --preset -M visual comma repeat-jump-reverse
bind --preset -M visual \$ end-of-line
bind --preset -M visual g,\$ end-of-line
bind --preset -M visual ^ beginning-of-line
bind --preset -M visual 0 beginning-of-line
bind --preset -M visual g,^ beginning-of-line
bind --preset -M visual _ beginning-of-line
bind --preset -M visual -m default v end-selection repaint-mode
bind --preset -M visual -m insert i end-selection repaint-mode
bind --preset -M visual -m insert I end-selection beginning-of-line repaint-mode
bind --preset -M visual -m insert c kill-selection end-selection repaint-mode
bind --preset -M visual -m insert s kill-selection end-selection repaint-mode
bind --preset -M visual -m default d kill-selection end-selection backward-char repaint-mode
bind --preset -M visual -m default x kill-selection end-selection repaint-mode
bind --preset -M visual -m default X kill-whole-line end-selection repaint-mode
bind --preset -M visual -m default y fish_vi_yank_selection end-selection repaint-mode
bind --preset -M visual -m default \",\*,y 'fish_clipboard_copy; commandline -f end-selection repaint-mode'
bind --preset -M visual -m default \",+,y 'fish_clipboard_copy; commandline -f end-selection repaint-mode'
bind --preset -M visual -m default \~ togglecase-selection end-selection repaint-mode
bind --preset -M visual -m default g,u downcase-selection end-selection repaint-mode
bind --preset -M visual -m default g,U upcase-selection end-selection repaint-mode
bind --preset \# __fish_toggle_comment_commandline
bind --preset -M visual \# __fish_toggle_comment_commandline
bind --preset -M replace \# __fish_toggle_comment_commandline

bind-end

wait
cat ./default.nix